Builder

Struct Builder 

pub struct Builder { /* private fields */ }
A message dialog builder.

Implementations

Source

impl Builder

pub fn title(self, title: impl Into<String>) -> Self

Sets the window title of the dialog.

By default, the title is generated from the Icon the dialog uses.

pub fn message(self, message: impl Into<String>) -> Self

Sets the message body.

The body can contain line breaks, and will be line-wrapped to fit into the dialog window.

pub fn icon(self, icon: Icon) -> Self

Sets the icon to display in the dialog.

By default, Icon::Info is used.

pub fn theme(self, theme: Theme) -> Self

Sets the dialog’s color theme.

By default, the OS theme is used.

pub fn button_preset(self, preset: ButtonPreset) -> Self

Sets the button preset to use.

By default, ButtonPreset::Close is used.

pub fn show(self) -> Result<Answer, Error>

Displays the dialog and blocks until the dialog is closed.

Returns an Answer indicating which dialog button was clicked.

Errors

An error may occur when communicating with the X server.